StoEvent

Type Alias StoEvent 

pub type StoEvent = StoEvent;

Aliased Type

pub enum StoEvent {
    FundraiserCreated {
        agent_did: IdentityId,
        offering_asset: AssetId,
        raising_asset: AssetId,
        fundraiser_id: FundraiserId,
        fundraiser_name: FundraiserName,
        fundraiser: Fundraiser<u64>,
    },
    Invested {
        investor_did: IdentityId,
        offering_asset: AssetId,
        fundraiser_id: FundraiserId,
        funding_asset: FundingAsset,
        offering_amount: u128,
        raise_amount: u128,
    },
    FundraiserFrozen {
        agent_did: IdentityId,
        offering_asset: AssetId,
        fundraiser_id: FundraiserId,
    },
    FundraiserUnfrozen {
        agent_did: IdentityId,
        offering_asset: AssetId,
        fundraiser_id: FundraiserId,
    },
    FundraiserWindowModified {
        agent_did: EventOnly<IdentityId>,
        offering_asset: AssetId,
        fundraiser_id: FundraiserId,
        old_start: u64,
        old_end: Option<u64>,
        new_start: u64,
        new_end: Option<u64>,
    },
    FundraiserClosed {
        agent_did: IdentityId,
        offering_asset: AssetId,
        fundraiser_id: FundraiserId,
    },
    FundraiserOffchainFundingEnabled {
        agent_did: IdentityId,
        offering_asset: AssetId,
        fundraiser_id: FundraiserId,
        ticker: Ticker,
    },
}

Variants



FundraiserCreated

A new fundraiser has been created.

[agent_did, offering_asset, raising_asset, fundraiser_id, fundraiser_name, fundraiser]

Fields

agent_did: IdentityId

Identity of the external agent who created the fundraiser.

offering_asset: AssetId

Asset being offered for sale in the fundraiser.

raising_asset: AssetId

Asset being accepted as payment in the fundraiser.

fundraiser_id: FundraiserId

Unique identifier for the fundraiser.

fundraiser_name: FundraiserName

Human-readable name of the fundraiser.

fundraiser: Fundraiser<u64>

Complete fundraiser configuration.



Invested

An investor successfully invested in the fundraiser.

[investor_did, offering_asset, fundraiser_id, funding_asset, offering_amount, raise_amount]

Fields

investor_did: IdentityId

Identity of the investor.

offering_asset: AssetId

Asset being purchased.

fundraiser_id: FundraiserId

Fundraiser that was invested in.

funding_asset: FundingAsset

Type of funding used (on-chain or off-chain).

offering_amount: u128

Amount of offering asset purchased.

raise_amount: u128

Amount of raising asset spent.



FundraiserFrozen

A fundraiser has been frozen, preventing new investments.

[agent_did, offering_asset, fundraiser_id]

Fields

agent_did: IdentityId

Identity of the external agent who froze the fundraiser.

offering_asset: AssetId

Asset associated with the fundraiser.

fundraiser_id: FundraiserId

Fundraiser that was frozen.



FundraiserUnfrozen

A fundraiser has been unfrozen, allowing new investments.

[agent_did, offering_asset, fundraiser_id]

Fields

agent_did: IdentityId

Identity of the external agent who unfroze the fundraiser.

offering_asset: AssetId

Asset associated with the fundraiser.

fundraiser_id: FundraiserId

Fundraiser that was unfrozen.



FundraiserWindowModified

A fundraiser’s time window has been modified.

[agent_did, offering_asset, fundraiser_id, old_start, old_end, new_start, new_end]

Fields

agent_did: EventOnly<IdentityId>

Identity of the external agent who modified the window.

offering_asset: AssetId

Asset associated with the fundraiser.

fundraiser_id: FundraiserId

Fundraiser whose window was modified.

old_start: u64

Previous start time.

old_end: Option<u64>

Previous end time (if any).

new_start: u64

New start time.

new_end: Option<u64>

New end time (if any).



FundraiserClosed

A fundraiser has been permanently closed.

[agent_did, offering_asset, fundraiser_id]

Fields

agent_did: IdentityId

Identity of the external agent who closed the fundraiser.

offering_asset: AssetId

Asset associated with the fundraiser.

fundraiser_id: FundraiserId

Fundraiser that was closed.



FundraiserOffchainFundingEnabled

Off-chain funding has been enabled for a fundraiser.

[agent_did, offering_asset, fundraiser_id, ticker]

Fields

agent_did: IdentityId

Identity of the external agent who enabled off-chain funding.

offering_asset: AssetId

Asset associated with the fundraiser.

fundraiser_id: FundraiserId

Fundraiser for which off-chain funding was enabled.

ticker: Ticker

Ticker symbol of the off-chain asset.